==> CGJobMgr-1.2.7.tar.gz: CGJobMgr/CGJobMgr.module.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGJobMgr (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module for CMS Made Simple to manage jobs that take considerable
#  amounts of time to process.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE

$cgextensions = cms_join_path($gCms->config['root_path'],'modules',
			      'CGExtensions','CGExtensions.module.php');
if( !is_readable( $cgextensions ) )
{
  echo '<h1><font color="red">ERROR: The CGExtensions module could not be found.</font></h1>';
  return;
}
require_once($cgextensions);

class CGJobMgr extends CGExtensions
{
  private $_stats;

  public function InitializeAdmin()
  {
    $this->AddImageDir('icons');
  }

  public function InitializeFrontend()
  {
    $this->SetParameterType('runcount',CLEAN_INT);
    $this->SetParameterType('jobid',CLEAN_INT);
    $this->RestrictUnknownParams();
    $this->RegisterRoute('/'.$this->GetName().'\/process$/',
			 array('action'=>'process',
			       'showtemplate'=>'false'));
  }

  function GetName() {
    return get_class($this);
  }

  function GetFriendlyName() {
    return $this->Lang('friendlyname');
  }
  
  function GetVersion() {
    return '1.2.7';
  }

  function GetDependencies() {
    return array('CGExtensions'=>'1.30');
  }

  function MinimumCMSVersion() {
    return '1.10.2';
  }

  function LazyLoadAdmin() {
    return TRUE;
  }

  function GetHelp() {
    return @file_get_contents(dirname(__FILE__).'/help.inc');
  }
  
  function GetAuthor() {
    return 'calguy1000';
  }
  
  function GetAuthorEmail() {
    return 'calguy1000@gmail.com';
  }
  
  function GetChangeLog() {
    return @file_get_contents(dirname(__FILE__).'/changelog.html.inc');
  }

  function IsPluginModule() {
    return true;
  }

  function GetAdminDescription() {
    return $this->Lang('moddescription');
  }
  
  function HasAdmin() {
    return true;
  }
  
  function VisibleToAdminUser() {
    return $this->CheckPermission('Manage Jobs') ||
      $this->CheckPermission('Modify Site Preferences');
  }
  
  function HandlesEvents () {
    return false;
  }

  function InstallPostMessage() {
    return $this->Lang('postinstall');
  }

  function UninstallPostMessage() {
    return $this->Lang('postuninstall');
  }

  function GetEventHelp( $eventname ) {
    return $this->Lang('help_event_'.$eventname);
  }

  protected function SetStats($stats) {
    $this->_stats = $stats;
  }

  /**
   * Get Run Statistics
   *
   * @ignore
   * @internal
   */
  public function GetStats()
  {
    if( is_array($this->_stats) ) return $this->_stats;
  }
} // end of class

#
# EOF
#
?>

==> CGJobMgr-1.2.11.tar.gz: CGJobMgr/CGJobMgr.module.php <==
<?php
#BEGIN_LICENSE
#-------------------------------------------------------------------------
# Module: CGJobMgr (c) 2011 by Robert Campbell 
#         (calguy1000@cmsmadesimple.org)
#  An addon module for CMS Made Simple to manage jobs that take considerable
#  amounts of time to process.
# 
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# However, as a special exception to the GPL, this software is distributed
# as an addon module to CMS Made Simple.  You may not use this software
# in any Non GPL version of CMS Made simple, or in any version of CMS
# Made simple that does not indicate clearly and obviously in its admin 
# section that the site was built with CMS Made simple.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------
#END_LICENSE

$cgextensions = cms_join_path($gCms->config['root_path'],'modules',
			      'CGExtensions','CGExtensions.module.php');
if( !is_readable( $cgextensions ) )
{
  echo '<h1><font color="red">ERROR: The CGExtensions module could not be found.</font></h1>';
  return;
}
require_once($cgextensions);

class CGJobMgr extends CGExtensions
{
  private $_stats;

  public function InitializeAdmin()
  {
    $this->AddImageDir('icons');
  }

  public function InitializeFrontend()
  {
    $this->SetParameterType('runcount',CLEAN_INT);
    $this->SetParameterType('jobid',CLEAN_INT);
    $this->RestrictUnknownParams();
    $this->RegisterRoute('/'.$this->GetName().'\/process$/',
			 array('action'=>'process',
			       'showtemplate'=>'false'));
  }

  function GetName() {
    return get_class($this);
  }

  function GetFriendlyName() {
    return $this->Lang('friendlyname');
  }
  
  function GetVersion() {
    return '1.2.11';
  }

  function GetDependencies() {
    return array('CGExtensions'=>'1.30');
  }

  function MinimumCMSVersion() {
    return '1.11.1';
  }

  public function GetAdminSection() { return 'siteadmin'; }

  function LazyLoadAdmin() {
    return TRUE;
  }

  function GetHelp() {
    return @file_get_contents(dirname(__FILE__).'/help.inc');
  }
  
  function GetAuthor() {
    return 'calguy1000';
  }
  
  function GetAuthorEmail() {
    return 'calguy1000@gmail.com';
  }
  
  function GetChangeLog() {
    return @file_get_contents(dirname(__FILE__).'/changelog.html.inc');
  }

  function IsPluginModule() {
    return true;
  }

  function GetAdminDescription() {
    return $this->Lang('moddescription');
  }
  
  function HasAdmin() {
    return true;
  }
  
  function VisibleToAdminUser() {
    return $this->CheckPermission('Manage Jobs') ||
      $this->CheckPermission('Modify Site Preferences');
  }
  
  function HandlesEvents () {
    return false;
  }

  function InstallPostMessage() {
    return $this->Lang('postinstall');
  }

  function UninstallPostMessage() {
    return $this->Lang('postuninstall');
  }

  function GetEventHelp( $eventname ) {
    return $this->Lang('help_event_'.$eventname);
  }
} // end of class

#
# EOF
#
?>
